==> aws_clamav_malware_scanner_vpc-2.9.2.tar.gz: package/assets/lambda/code/move_file/lambda.py <==
import boto3
import logging
import urllib3

logger = logging.getLogger()
logger.setLevel(logging.INFO)
s3_client = boto3.client("s3", verify=False)

INPROGRESS = "IN PROGRESS"
CLEAN = "CLEAN"
INFECTED = "INFECTED"
ERROR = "ERROR"
SKIP = "N/A"
MISSMATCH = "MISSMATCH"

def lambda_handler(event, context):
    input_bucket = event['input_bucket']
    input_key = event['input_key']
    status = event['status']

    infected_bucket = event['infected_bucket']
    clean_bucket = event['clean_bucket']

    if status == "INFECTED":
        move_file(input_bucket, input_key, infected_bucket)
    elif status == "CLEAN":
        move_file(event, input_bucket, input_key, clean_bucket)

def update_object_tag(source_bucket, source_key, tag_key, tag_value):
    try:
        tagging = {
            'TagSet': [
                {
                    'Key': tag_key,
                    'Value': tag_value
                }
            ]
        }
        s3_client.put_object_tagging(
            Bucket=source_bucket,
            Key=source_key,
            Tagging=tagging
        )
        logger.info(f"Successfully updated tag {tag_key} to {tag_value} for file {source_key} in bucket {source_bucket}")
    except Exception as e:
        logger.error(f"Error updating tag {tag_key} to {tag_value} for file {source_key} in bucket {source_bucket}: {e}")
        raise e

def move_file(event, source_bucket, source_key, target_bucket):
    try:
        # Retrieve the metadata of an S3 object
        response = s3_client.head_object(Bucket=source_bucket, Key=source_key)
        etag = response['ETag'].strip('"')

        # Verify the etag from the event
        if etag != event['etag']:
            logger.error(f"ETag mismatch: expected {event['etag']}, got {etag}")
            message = {
                "state": "FAILED",
                'clean_bucket': event['clean_bucket'],
                'etag': event['etag'],
                'infected_bucket': event['infected_bucket'],
                'input_bucket': event['input_bucket'],
                'input_key': source_key,
                'message': f"!ETag mismatch: expected {event['etag']}, got {etag}, Status Changed: {event['status']} -> ETagMismatch",
                'source': event['source'],
                'status': event['status']
            }
            update_object_tag(source_bucket, source_key, 'scan-status', 'ETagMismatch')
            return message

        copy_source = {'Bucket': source_bucket, 'Key': source_key}
        s3_client.copy_object(
            Bucket=target_bucket,
            CopySource=copy_source,
            Key=source_key,
            TaggingDirective='COPY'
        )
        s3_client.delete_object(Bucket=source_bucket, Key=source_key)
        logger.info(f"Successfully moved file {source_key} from {source_bucket} to {target_bucket}")
        message = {
            "state": "FINISHED",
            'clean_bucket': event['clean_bucket'],
            'etag': event['etag'],
            'infected_bucket': event['infected_bucket'],
            'input_bucket': event['input_bucket'],
            'input_key': source_key,
            'message': f"!ETag mismatch: expected {event['etag']}, got {etag}, Status Changed: {event['status']} -> ETagMismatch",
            'source': event['source'],
            'status': event['status']
        }
        return message
    except Exception as e:
        logger.error(f"Error moving file {source_key} from {source_bucket} to {target_bucket}: {e}")
        raise e

# context = None
# event = {
#     'clean_bucket': 'cleanbucketname-495526829652',
#     'etag': '51da8dc0bd15c796273af86e68d8fd70',
#     'infected_bucket': 'infectedbucketname-495526829652',
#     'input_bucket': 'awssecures3stack-rbucket315e56245-likugkivtiof',
#     'input_key': 'README.md',
#     'message': 'LibClamAV Warning: Max file-size was set to 4000000000 bytes. Unfortunately, scanning files greater than 2147483647 bytes (2 ...ta read: 0.00 MB (ratio 0.00:1)\nTime: 8.086 sec (0 m 8 s)\nStart Date: 2025:02:06 18:55:01\nEnd Date:   2025:02:06 18:55:09\n',
#     'source': 'serverless-clamscan',
#     'status': 'CLEAN'
# }
# lambda_handler(event, context)

==> aws_clamav_malware_scanner_vpc-2.12.0.tar.gz: package/assets/lambda/code/move_file/lambda.py <==
import boto3
import logging
import urllib3

logger = logging.getLogger()
logger.setLevel(logging.INFO)
s3_client = boto3.client("s3", verify=False)

INPROGRESS = "IN PROGRESS"
CLEAN = "CLEAN"
INFECTED = "INFECTED"
ERROR = "ERROR"
SKIP = "N/A"
MISSMATCH = "MISSMATCH"

def lambda_handler(event, context):
    input_bucket = event['input_bucket']
    input_key = event['input_key']
    status = event['status']

    infected_bucket = event['infected_bucket']
    clean_bucket = event['clean_bucket']

    if status == "INFECTED":
        move_file(event, input_bucket, input_key, infected_bucket)
    elif status == "CLEAN":
        move_file(event, input_bucket, input_key, clean_bucket)

def update_object_tag(source_bucket, source_key, tag_key, tag_value):
    try:
        tagging = {
            'TagSet': [
                {
                    'Key': tag_key,
                    'Value': tag_value
                }
            ]
        }
        s3_client.put_object_tagging(
            Bucket=source_bucket,
            Key=source_key,
            Tagging=tagging
        )
        logger.info(f"Successfully updated tag {tag_key} to {tag_value} for file {source_key} in bucket {source_bucket}")
    except Exception as e:
        logger.error(f"Error updating tag {tag_key} to {tag_value} for file {source_key} in bucket {source_bucket}: {e}")
        raise e

def move_file(event, source_bucket, source_key, target_bucket):
    try:
        # Retrieve the metadata of an S3 object
        response = s3_client.head_object(Bucket=source_bucket, Key=source_key)
        etag = response['ETag'].strip('"')

        # Verify the etag from the event
        if etag != event['etag']:
            logger.error(f"ETag mismatch: expected {event['etag']}, got {etag}")
            message = {
                "state": "FAILED",
                'clean_bucket': event['clean_bucket'],
                'etag': event['etag'],
                'infected_bucket': event['infected_bucket'],
                'input_bucket': event['input_bucket'],
                'input_key': source_key,
                'message': f"!ETag mismatch: expected {event['etag']}, got {etag}, Status Changed: {event['status']} -> ETagMismatch",
                'source': event['source'],
                'status': event['status']
            }
            update_object_tag(source_bucket, source_key, 'scan-status', 'ETagMismatch')
            return message

        copy_source = {'Bucket': source_bucket, 'Key': source_key}
        s3_client.copy_object(
            Bucket=target_bucket,
            CopySource=copy_source,
            Key=source_key,
            TaggingDirective='COPY'
        )
        s3_client.delete_object(Bucket=source_bucket, Key=source_key)
        logger.info(f"Successfully moved file {source_key} from {source_bucket} to {target_bucket}")
        message = {
            "state": "FINISHED",
            'clean_bucket': event['clean_bucket'],
            'etag': event['etag'],
            'infected_bucket': event['infected_bucket'],
            'input_bucket': event['input_bucket'],
            'input_key': source_key,
            'message': f"!ETag mismatch: expected {event['etag']}, got {etag}, Status Changed: {event['status']} -> ETagMismatch",
            'source': event['source'],
            'status': event['status']
        }
        return message
    except Exception as e:
        logger.error(f"Error moving file {source_key} from {source_bucket} to {target_bucket}: {e}")
        raise e

# context = None
# event = {
#     'clean_bucket': 'cleanbucketname-495526829652',
#     'etag': '51da8dc0bd15c796273af86e68d8fd70',
#     'infected_bucket': 'infectedbucketname-495526829652',
#     'input_bucket': 'awssecures3stack-rbucket315e56245-likugkivtiof',
#     'input_key': 'README.md',
#     'message': 'LibClamAV Warning: Max file-size was set to 4000000000 bytes. Unfortunately, scanning files greater than 2147483647 bytes (2 ...ta read: 0.00 MB (ratio 0.00:1)\nTime: 8.086 sec (0 m 8 s)\nStart Date: 2025:02:06 18:55:01\nEnd Date:   2025:02:06 18:55:09\n',
#     'source': 'serverless-clamscan',
#     'status': 'CLEAN'
# }
# lambda_handler(event, context)
